@@ -10,6 +10,14 @@ import cro_validate.classes.util_classes as Utils
 
 
 def instantiate_class(fqn, *args, **kw):
+	"""
+	Create instance of class based on fully qualified class name.
+
+	:param str fqn: Fully qualified class name (module_name.class_name).
+	:param args: List of positional args to pass to constructor.
+	:param kw: Dict of named args to pass to constructor.
+	:return: New instance of class.
+	"""
 	module_name, class_name = Utils.ClassName.class_fqn_parts(fqn)
 	if module_name == 'builtins' and class_name == 'NoneType':
 		return None
@@ -23,11 +31,18 @@ def instantiate_class(fqn, *args, **kw):
 
 
 class Meta:
+	"""
+	:ref:`Definition` meta interface.
+	"""
+
 	def initialize(self, definition, **kw):
 		raise NotImplementedError()
 
 
 class DefaultDefinitionMeta(Meta):
+	"""
+	Default :ref:`Definition` meta implementation.
+	"""
 	component_name_strategy = NameStrategies.DefaultComponentNameStrategy()
 	schema_name = None
 	component_name = None
@@ -47,6 +62,10 @@ class DefaultDefinitionMeta(Meta):
 
 
 class InstantiateValueProvider:
+	"""
+	Create instance of Definition.
+	"""
+
 	def __init__(self):
 		pass
 
@@ -104,20 +123,23 @@ class InstantiateValueProvider:
 
 
 class Definition:
-	name = None
-	aliases = []
-	description = ''
-	data_type = DataType.String
-	data_format = None
-	default_value = Utils.Empty
-	examples = None
-	nullable = False
-	deprecated = False
-	internal = False
-	rules = []
-	base_version = 'base'
-	final_version = None
-	version_conversion = None
+	"""
+	Define value meta, format, and schema.
+	"""
+	name = None  #: Primary name to index and identify this definition.
+	aliases = []  #: List of aliases to index.
+	description = ''  #: Description field for use with docs, etc.
+	data_type = DataType.String  #: The data type. See :ref:`DataType`.
+	data_format = None  #: Client lib defined format constant. May be None.
+	default_value = Utils.Empty  #: Default value. Will be :ref:`ro_validate.classes.util_classes` if not specified.
+	examples = None  #: List of examples for use in docs, testing, etc.
+	nullable = False  #: Can be assigned None when True, otherwise None will raise input error during validation.
+	deprecated = False  #: Client lib value for use with docs, etc.
+	internal = False  #: Client lib value for use with docs, etc.
+	rules = []  #: List of validation :ref:`cro_validate.classes.rule_classes.Rule`. Executed in sequence.
+	base_version = 'base'  #: Base version. Defines start point in version history. See the version guide for more info.
+	final_version = None  #: Final version. Defines endpoint in version history. See the version guide for more info.
+	version_conversion = None  #: Logic for converting from version to version.
 	mutations = None
 	meta = DefaultDefinitionMeta()
 
@@ -711,10 +733,6 @@ class DefinitionJsonDeserializer:
 			kw['base_version'] = obj['base_version']
 		if 'final_version' in obj:
 			kw['final_version'] = obj['final_version']
-		if 'base_version_conversion' in obj:
-			config = obj['base_version_conversion']['config']
-			type_fqn = obj['base_version_conversion']['type']
-			kw['base_version_conversion'] = instantiate_class(type_fqn, **config)
 		if 'versions' in obj:
 			kw['versions'] = {}
 			for version in obj['versions']:
@@ -745,6 +763,7 @@ class Index:
 	_versions_idx = {'base': 0}
 	_versions_display_names = {'base': None}
 	_json_dict = {}
+	_default_version = None
 
 	def _resolve_definition_name(definition_or_name, error_on_missing=True):
 		definition_name = definition_or_name
@@ -806,8 +825,20 @@ class Index:
 		result.extend(Index._versions)
 		return result
 
+	def set_default_version(default_version):
+		if default_version not in Index._versions_idx:
+			msg = 'Version not found (default_version={0}).'.format(default_version)
+			raise Config.exception_factory.create_internal_error(
+					'set_default_version',
+					msg
+				)
+		Index._default_version = default_version
+
 	def get_latest_version():
-		return Index._versions[-1]
+		i = -1
+		if Index._default_version is not None:
+			i = Index.versions_idx[Index._default_version]
+		return Index._versions[i]
 
 	def get_first_version():
 		return Index._versions[1]
@@ -970,12 +1001,9 @@ class Index:
 			return False
 		return True
 
-	def as_dict():
-		return Index._idx
-
 	def to_json_dict():
 		aliases = set()
-		keys = [k for k in Index.as_dict()]
+		keys = [k for k in Index._idx]
 		keys.sort()
 		for k in keys:
 			definition = Index.get(k)
@@ -1081,8 +1109,10 @@ class Index:
 			elif mutation.action == VersionMutationType.RenameField:
 				old_field_name = mutation.config['field_name']
 				old_field = mutated_model[old_field_name]
+				new_field = old_field.copy()
+				new_field.mutate(input_name=mutation.config['field_name'])
 				del mutated_model[old_field_name]
-				mutated_model[mutation.config['new_field_name']] = old_field
+				mutated_model[mutation.config['new_field_name']] = new_field
 		return mutated_model
 
 	def _execute_field_init(model, field_init_actions):
@@ -1122,8 +1152,6 @@ class Index:
 		model = Index._execute_field_init(model, schema.field_init_actions)
 		return model
 
-	t = 0
-
 	def register_definition(
 				name,
 				aliases,
@@ -1138,7 +1166,6 @@ class Index:
 				rules,
 				meta,
 				base_version=Utils.Empty,
-				base_version_conversion=Utils.Empty,
 				final_version=Utils.Empty,
 				versions=Utils.Empty
 			):
